/**
 * Converts a camelCase string to snake_case.
 *
 * @param str - The camelCase string to be converted.
 * @param options - Optional configuration object.
 * @param options.separator - The separator to use between words. Defaults to "_".
 * @returns The snake_case representation of the input string.
 */
export declare function decamelize(str: string, options?: {
    separator?: string;
}): string;
/**
 * Converts the keys of an object to snake_case.
 *
 * @param obj - The object whose keys are to be converted. Can be nested and may include arrays.
 * @param sep - The separator to use between words in the keys. Defaults to "-".
 * @returns A new object with keys in snake_case format, or the original value if not an object.
 */
export declare function snakeCaseKeys<T>(obj: T, sep?: string): T;
/**
 * Ensures that a directory exists, creating it if necessary.
 *
 * @param outdir - The path to the directory to check or create.
 */
export declare function ensureDirSync(outdir: string): void;
/**
 * Cleans an object by removing keys with undefined values.
 *
 * @param obj - The object to be cleaned. If undefined, returns undefined.
 * @returns A new object without undefined values, or undefined if the cleaned object is empty or the input is undefined.
 */
export declare function cleanObject<T extends Record<string, unknown>>(obj?: T): T | undefined;
/**
 * Retrieves the version from the package.json file.
 *
 * @returns The version string from package.json if it exists, otherwise undefined.
 */
export declare function getPackageVersion(): string | undefined;
/**
 * Utility function to check if a value is an object.
 *
 * @param value - The value to check.
 * @returns True if the value is an object, false otherwise.
 */
export declare function isObject(value: unknown): value is Record<string, unknown>;
